Class: Aws::S3Files::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::S3Files::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-s3files/client.rb,
sig/client.rbs
Overview
An API client for S3Files. To construct a client, you need to configure a :region and :credentials.
client = Aws::S3Files::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAccessPointResponseSuccess, _CreateFileSystemResponseSuccess, _CreateMountTargetResponseSuccess, _GetAccessPointResponseSuccess, _GetFileSystemPolicyResponseSuccess, _GetFileSystemResponseSuccess, _GetMountTargetResponseSuccess, _GetSynchronizationConfigurationResponseSuccess, _ListAccessPointsResponseSuccess, _ListFileSystemsResponseSuccess, _ListMountTargetsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutFileSystemPolicyResponseSuccess, _PutSynchronizationConfigurationResponseSuccess, _UpdateMountTargetResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_access_point(params = {}) ⇒ Types::CreateAccessPointResponse
Creates an S3 File System Access Point for application-specific access with POSIX user identity and root directory enforcement.
-
#create_file_system(params = {}) ⇒ Types::CreateFileSystemResponse
Creates an S3 File System resource scoped to a bucket or prefix within a bucket, enabling file system access to S3 data.
-
#create_mount_target(params = {}) ⇒ Types::CreateMountTargetResponse
Creates a mount target resource as an endpoint for mounting the S3 File System from compute resources in a specific Availability Zone and VPC.
-
#delete_access_point(params = {}) ⇒ Struct
Deletes an S3 File System Access Point.
-
#delete_file_system(params = {}) ⇒ Struct
Deletes an S3 File System.
-
#delete_file_system_policy(params = {}) ⇒ Struct
Deletes the IAM resource policy of an S3 File System.
-
#delete_mount_target(params = {}) ⇒ Struct
Deletes the specified mount target.
-
#get_access_point(params = {}) ⇒ Types::GetAccessPointResponse
Returns resource information for an S3 File System Access Point.
-
#get_file_system(params = {}) ⇒ Types::GetFileSystemResponse
Returns resource information for the specified S3 File System including status, configuration, and metadata.
-
#get_file_system_policy(params = {}) ⇒ Types::GetFileSystemPolicyResponse
Returns the IAM resource policy of an S3 File System.
-
#get_mount_target(params = {}) ⇒ Types::GetMountTargetResponse
Returns detailed resource information for the specified mount target including network configuration.
-
#get_synchronization_configuration(params = {}) ⇒ Types::GetSynchronizationConfigurationResponse
Returns the synchronization configuration for the specified S3 File System, including import data rules and expiration data rules.
-
#list_access_points(params = {}) ⇒ Types::ListAccessPointsResponse
Returns resource information for all S3 File System Access Points associated with the specified S3 File System.
-
#list_file_systems(params = {}) ⇒ Types::ListFileSystemsResponse
Returns a list of all S3 File Systems owned by the account with optional filtering by bucket.
-
#list_mount_targets(params = {}) ⇒ Types::ListMountTargetsResponse
Returns resource information for all mount targets with optional filtering by file system, access point, and VPC.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags for S3 Files resources.
-
#put_file_system_policy(params = {}) ⇒ Struct
Creates or replaces the IAM resource policy for an S3 File System to control access permissions.
-
#put_synchronization_configuration(params = {}) ⇒ Struct
Creates or updates the synchronization configuration for the specified S3 File System, including import data rules and expiration data rules.
-
#tag_resource(params = {}) ⇒ Struct
Creates tags for S3 Files resources using standard Amazon Web Services tagging APIs.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from S3 Files resources.
-
#update_mount_target(params = {}) ⇒ Types::UpdateMountTargetResponse
Updates the mount target resource, specifically security group configurations.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-s3files/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1553 1554 1555 |
# File 'lib/aws-sdk-s3files/client.rb', line 1553 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1556 1557 1558 |
# File 'lib/aws-sdk-s3files/client.rb', line 1556 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 |
# File 'lib/aws-sdk-s3files/client.rb', line 1526 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::S3Files') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-s3files' context[:gem_version] = '1.5.0' Seahorse::Client::Request.new(handlers, context) end |
#create_access_point(params = {}) ⇒ Types::CreateAccessPointResponse
Creates an S3 File System Access Point for application-specific access with POSIX user identity and root directory enforcement. Access points provide a way to manage access to shared datasets in multi-tenant scenarios.
95 |
# File 'sig/client.rbs', line 95
def create_access_point: (
|
#create_file_system(params = {}) ⇒ Types::CreateFileSystemResponse
Creates an S3 File System resource scoped to a bucket or prefix within a bucket, enabling file system access to S3 data. To create a file system, you need an S3 bucket and an IAM role that grants the service permission to access the bucket.
137 |
# File 'sig/client.rbs', line 137
def create_file_system: (
|
#create_mount_target(params = {}) ⇒ Types::CreateMountTargetResponse
Creates a mount target resource as an endpoint for mounting the S3 File System from compute resources in a specific Availability Zone and VPC. Mount targets provide network access to the file system.
169 |
# File 'sig/client.rbs', line 169
def create_mount_target: (
|
#delete_access_point(params = {}) ⇒ Struct
Deletes an S3 File System Access Point. This operation is irreversible.
180 |
# File 'sig/client.rbs', line 180
def delete_access_point: (
|
#delete_file_system(params = {}) ⇒ Struct
Deletes an S3 File System. You can optionally force deletion of a file system that has pending export data.
186 |
# File 'sig/client.rbs', line 186
def delete_file_system: (
|
#delete_file_system_policy(params = {}) ⇒ Struct
Deletes the IAM resource policy of an S3 File System.
193 |
# File 'sig/client.rbs', line 193
def delete_file_system_policy: (
|
#delete_mount_target(params = {}) ⇒ Struct
Deletes the specified mount target. This operation is irreversible.
199 |
# File 'sig/client.rbs', line 199
def delete_mount_target: (
|
#get_access_point(params = {}) ⇒ Types::GetAccessPointResponse
Returns resource information for an S3 File System Access Point.
218 |
# File 'sig/client.rbs', line 218
def get_access_point: (
|
#get_file_system(params = {}) ⇒ Types::GetFileSystemResponse
Returns resource information for the specified S3 File System including status, configuration, and metadata.
240 |
# File 'sig/client.rbs', line 240
def get_file_system: (
|
#get_file_system_policy(params = {}) ⇒ Types::GetFileSystemPolicyResponse
Returns the IAM resource policy of an S3 File System.
251 |
# File 'sig/client.rbs', line 251
def get_file_system_policy: (
|
#get_mount_target(params = {}) ⇒ Types::GetMountTargetResponse
Returns detailed resource information for the specified mount target including network configuration.
272 |
# File 'sig/client.rbs', line 272
def get_mount_target: (
|
#get_synchronization_configuration(params = {}) ⇒ Types::GetSynchronizationConfigurationResponse
Returns the synchronization configuration for the specified S3 File System, including import data rules and expiration data rules.
284 |
# File 'sig/client.rbs', line 284
def get_synchronization_configuration: (
|
#list_access_points(params = {}) ⇒ Types::ListAccessPointsResponse
Returns resource information for all S3 File System Access Points associated with the specified S3 File System.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
295 |
# File 'sig/client.rbs', line 295
def list_access_points: (
|
#list_file_systems(params = {}) ⇒ Types::ListFileSystemsResponse
Returns a list of all S3 File Systems owned by the account with optional filtering by bucket.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
308 |
# File 'sig/client.rbs', line 308
def list_file_systems: (
|
#list_mount_targets(params = {}) ⇒ Types::ListMountTargetsResponse
Returns resource information for all mount targets with optional filtering by file system, access point, and VPC.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
321 |
# File 'sig/client.rbs', line 321
def list_mount_targets: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags for S3 Files resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
335 |
# File 'sig/client.rbs', line 335
def list_tags_for_resource: (
|
#put_file_system_policy(params = {}) ⇒ Struct
Creates or replaces the IAM resource policy for an S3 File System to control access permissions.
346 |
# File 'sig/client.rbs', line 346
def put_file_system_policy: (
|
#put_synchronization_configuration(params = {}) ⇒ Struct
Creates or updates the synchronization configuration for the specified S3 File System, including import data rules and expiration data rules.
356 |
# File 'sig/client.rbs', line 356
def put_synchronization_configuration: (
|
#tag_resource(params = {}) ⇒ Struct
Creates tags for S3 Files resources using standard Amazon Web Services tagging APIs.
375 |
# File 'sig/client.rbs', line 375
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from S3 Files resources.
387 |
# File 'sig/client.rbs', line 387
def untag_resource: (
|
#update_mount_target(params = {}) ⇒ Types::UpdateMountTargetResponse
Updates the mount target resource, specifically security group configurations.
409 |
# File 'sig/client.rbs', line 409
def update_mount_target: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1546 1547 1548 |
# File 'lib/aws-sdk-s3files/client.rb', line 1546 def waiter_names [] end |