Class: Aws::S3Files::Types::CreateFileSystemResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Files::Types::CreateFileSystemResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3files/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The Amazon Resource Name (ARN) of the S3 bucket associated with the file system.
-
#client_token ⇒ String
The client token used for idempotency.
-
#creation_time ⇒ Time
The time when the file system was created, in seconds since 1970-01-01T00:00:00Z (Unix epoch time).
-
#file_system_arn ⇒ String
The ARN for the S3 file system, in the format ‘arn:aws:s3files:region:account-id:file-system/file-system-id`.
-
#file_system_id ⇒ String
The ID of the file system, assigned by S3 Files.
-
#kms_key_id ⇒ String
The ARN or alias of the KMS key used for encryption.
-
#name ⇒ String
The name of the file system, derived from the ‘Name` tag if present.
-
#owner_id ⇒ String
The Amazon Web Services account ID of the file system owner.
-
#prefix ⇒ String
The prefix within the S3 bucket that scopes the file system access.
-
#role_arn ⇒ String
The ARN of the IAM role used for S3 access.
-
#status ⇒ String
The lifecycle state of the file system.
-
#status_message ⇒ String
Additional information about the file system status.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the file system.
Instance Attribute Details
#bucket ⇒ String
The Amazon Resource Name (ARN) of the S3 bucket associated with the file system.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The client token used for idempotency.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the file system was created, in seconds since 1970-01-01T00:00:00Z (Unix epoch time).
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#file_system_arn ⇒ String
The ARN for the S3 file system, in the format ‘arn:aws:s3files:region:account-id:file-system/file-system-id`.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#file_system_id ⇒ String
The ID of the file system, assigned by S3 Files. This ID is used to reference the file system in subsequent API calls.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN or alias of the KMS key used for encryption.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the file system, derived from the ‘Name` tag if present.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The Amazon Web Services account ID of the file system owner.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
The prefix within the S3 bucket that scopes the file system access.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role used for S3 access.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The lifecycle state of the file system. Valid values are: ‘AVAILABLE` (the file system is available for use), `CREATING` (the file system is being created), `DELETING` (the file system is being deleted), `DELETED` (the file system has been deleted), `ERROR` (the file system is in an error state), or `UPDATING` (the file system is being updated).
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
Additional information about the file system status. This field provides more details when the status is ‘ERROR`, or during state transitions.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the file system.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-s3files/types.rb', line 272 class CreateFileSystemResponse < Struct.new( :creation_time, :file_system_arn, :file_system_id, :bucket, :prefix, :client_token, :kms_key_id, :status, :status_message, :role_arn, :owner_id, :tags, :name) SENSITIVE = [] include Aws::Structure end |