Class: Aws::S3Files::Types::CreateMountTargetResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3files/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone_idString

The unique and consistent identifier of the Availability Zone where the mount target is located. For example, ‘use1-az1` is an Availability Zone ID for the `us-east-1` Amazon Web Services Region, and it has the same location in every Amazon Web Services account.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_idString

The ID of the S3 File System associated with the mount target.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#ipv4_addressString

The IPv4 address assigned to the mount target.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#ipv6_addressString

The IPv6 address assigned to the mount target.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#mount_target_idString

The ID of the mount target, assigned by S3 Files. This ID is used to reference the mount target in subsequent API calls.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface that S3 Files created when it created the mount target. This network interface is managed by the service.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The Amazon Web Services account ID of the mount target owner.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<String>

The security groups associated with the mount target’s network interface.

Returns:

  • (Array<String>)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The lifecycle state of the mount target. Valid values are: ‘AVAILABLE` (the mount target is available for use), `CREATING` (the mount target is being created), `DELETING` (the mount target is being deleted), `DELETED` (the mount target has been deleted), or `ERROR` (the mount target is in an error state), or `UPDATING` (the mount target is being updated).

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

Additional information about the mount target status. This field provides more details when the status is ‘ERROR`, or during state transitions.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet where the mount target is located.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC where the mount target is located.

Returns:

  • (String)


410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/aws-sdk-s3files/types.rb', line 410

class CreateMountTargetResponse < Struct.new(
  :availability_zone_id,
  :owner_id,
  :mount_target_id,
  :file_system_id,
  :subnet_id,
  :ipv4_address,
  :ipv6_address,
  :network_interface_id,
  :vpc_id,
  :security_groups,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end