Class: Aws::S3Files::Types::GetSynchronizationConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Files::Types::GetSynchronizationConfigurationResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3files/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expiration_data_rules ⇒ Array<Types::ExpirationDataRule>
An array of expiration data rules that control when cached data expires from the file system.
-
#import_data_rules ⇒ Array<Types::ImportDataRule>
An array of import data rules that control how data is imported from S3 into the file system.
-
#latest_version_number ⇒ Integer
The version number of the synchronization configuration.
Instance Attribute Details
#expiration_data_rules ⇒ Array<Types::ExpirationDataRule>
An array of expiration data rules that control when cached data expires from the file system.
824 825 826 827 828 829 830 |
# File 'lib/aws-sdk-s3files/types.rb', line 824 class GetSynchronizationConfigurationResponse < Struct.new( :latest_version_number, :import_data_rules, :expiration_data_rules) SENSITIVE = [] include Aws::Structure end |
#import_data_rules ⇒ Array<Types::ImportDataRule>
An array of import data rules that control how data is imported from S3 into the file system.
824 825 826 827 828 829 830 |
# File 'lib/aws-sdk-s3files/types.rb', line 824 class GetSynchronizationConfigurationResponse < Struct.new( :latest_version_number, :import_data_rules, :expiration_data_rules) SENSITIVE = [] include Aws::Structure end |
#latest_version_number ⇒ Integer
The version number of the synchronization configuration. Use this value with ‘PutSynchronizationConfiguration` to ensure optimistic concurrency control.
824 825 826 827 828 829 830 |
# File 'lib/aws-sdk-s3files/types.rb', line 824 class GetSynchronizationConfigurationResponse < Struct.new( :latest_version_number, :import_data_rules, :expiration_data_rules) SENSITIVE = [] include Aws::Structure end |