Class: Aws::S3Files::Types::ImportDataRule

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3files/types.rb

Overview

Specifies a rule that controls how data is imported from S3 into the file system.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#prefixString

The S3 key prefix that scopes this import rule. Only objects with keys beginning with this prefix are subject to the rule.

Returns:

  • (String)


854
855
856
857
858
859
860
# File 'lib/aws-sdk-s3files/types.rb', line 854

class ImportDataRule < Struct.new(
  :prefix,
  :trigger,
  :size_less_than)
  SENSITIVE = []
  include Aws::Structure
end

#size_less_thanInteger

The upper size limit in bytes for this import rule. Only objects with a size strictly less than this value will have data imported into the file system.

Returns:

  • (Integer)


854
855
856
857
858
859
860
# File 'lib/aws-sdk-s3files/types.rb', line 854

class ImportDataRule < Struct.new(
  :prefix,
  :trigger,
  :size_less_than)
  SENSITIVE = []
  include Aws::Structure
end

#triggerString

The event that triggers data import. Valid values are ‘ON_DIRECTORY_FIRST_ACCESS` (import when a directory is first accessed) and `ON_FILE_ACCESS` (import when a file is accessed).

Returns:

  • (String)


854
855
856
857
858
859
860
# File 'lib/aws-sdk-s3files/types.rb', line 854

class ImportDataRule < Struct.new(
  :prefix,
  :trigger,
  :size_less_than)
  SENSITIVE = []
  include Aws::Structure
end