Class: Aws::S3Files::Types::ListFileSystemsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3files/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

Optional filter to list only file systems associated with the specified S3 bucket Amazon Resource Name (ARN). If provided, only file systems that provide access to this bucket will be returned in the response.

Returns:

  • (String)


1046
1047
1048
1049
1050
1051
1052
# File 'lib/aws-sdk-s3files/types.rb', line 1046

class ListFileSystemsRequest < Struct.new(
  :bucket,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of file systems to return in a single response. If not specified, up to 100 file systems are returned.

Returns:

  • (Integer)


1046
1047
1048
1049
1050
1051
1052
# File 'lib/aws-sdk-s3files/types.rb', line 1046

class ListFileSystemsRequest < Struct.new(
  :bucket,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token returned from a previous call to continue listing file systems.

Returns:

  • (String)


1046
1047
1048
1049
1050
1051
1052
# File 'lib/aws-sdk-s3files/types.rb', line 1046

class ListFileSystemsRequest < Struct.new(
  :bucket,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end