Class: Aws::S3Files::Types::ListFileSystemsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Files::Types::ListFileSystemsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3files/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_systems ⇒ Array<Types::ListFileSystemsDescription>
An array of file system descriptions.
-
#next_token ⇒ String
A pagination token to use in a subsequent request if more results are available.
Instance Attribute Details
#file_systems ⇒ Array<Types::ListFileSystemsDescription>
An array of file system descriptions.
1065 1066 1067 1068 1069 1070 |
# File 'lib/aws-sdk-s3files/types.rb', line 1065 class ListFileSystemsResponse < Struct.new( :next_token, :file_systems) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token to use in a subsequent request if more results are available.
1065 1066 1067 1068 1069 1070 |
# File 'lib/aws-sdk-s3files/types.rb', line 1065 class ListFileSystemsResponse < Struct.new( :next_token, :file_systems) SENSITIVE = [] include Aws::Structure end |