Class: Aws::S3Files::Types::ListMountTargetsDescription

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3files/types.rb

Overview

Contains information about a mount target returned in list operations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone_idString

The Availability Zone ID where the mount target is located.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_idString

The ID of the S3 File System.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipv4_addressString

The IPv4 address of the mount target.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipv6_addressString

The IPv6 address of the mount target.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#mount_target_idString

The ID of the mount target.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface associated with the mount target.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The Amazon Web Services account ID of the mount target owner.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the mount target.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

Additional information about the mount target status.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet where the mount target is located.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC where the mount target is located.

Returns:

  • (String)


1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/aws-sdk-s3files/types.rb', line 1120

class ListMountTargetsDescription < Struct.new(
  :availability_zone_id,
  :file_system_id,
  :ipv4_address,
  :ipv6_address,
  :status,
  :status_message,
  :mount_target_id,
  :network_interface_id,
  :owner_id,
  :subnet_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end