Class: Aws::S3Files::Types::ListMountTargetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3files/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_idString

Optional filter to list only mount targets associated with the specified access point ID or Amazon Resource Name (ARN).

Returns:

  • (String)


1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-s3files/types.rb', line 1159

class ListMountTargetsRequest < Struct.new(
  :file_system_id,
  :access_point_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_idString

Optional filter to list only mount targets associated with the specified S3 File System ID or Amazon Resource Name (ARN). If provided, only mount targets for this file system will be returned in the response.

Returns:

  • (String)


1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-s3files/types.rb', line 1159

class ListMountTargetsRequest < Struct.new(
  :file_system_id,
  :access_point_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of mount targets to return in a single response.

Returns:

  • (Integer)


1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-s3files/types.rb', line 1159

class ListMountTargetsRequest < Struct.new(
  :file_system_id,
  :access_point_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token returned from a previous call to continue listing mount targets.

Returns:

  • (String)


1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-s3files/types.rb', line 1159

class ListMountTargetsRequest < Struct.new(
  :file_system_id,
  :access_point_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end