Class: Aws::S3Files::Types::ListFileSystemsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Files::Types::ListFileSystemsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3files/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
Optional filter to list only file systems associated with the specified S3 bucket Amazon Resource Name (ARN).
-
#max_results ⇒ Integer
The maximum number of file systems to return in a single response.
-
#next_token ⇒ String
A pagination token returned from a previous call to continue listing file systems.
Instance Attribute Details
#bucket ⇒ String
Optional filter to list only file systems associated with the specified S3 bucket Amazon Resource Name (ARN). If provided, only file systems that provide access to this bucket will be returned in the response.
1046 1047 1048 1049 1050 1051 1052 |
# File 'lib/aws-sdk-s3files/types.rb', line 1046 class ListFileSystemsRequest < Struct.new( :bucket, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of file systems to return in a single response. If not specified, up to 100 file systems are returned.
1046 1047 1048 1049 1050 1051 1052 |
# File 'lib/aws-sdk-s3files/types.rb', line 1046 class ListFileSystemsRequest < Struct.new( :bucket, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token returned from a previous call to continue listing file systems.
1046 1047 1048 1049 1050 1051 1052 |
# File 'lib/aws-sdk-s3files/types.rb', line 1046 class ListFileSystemsRequest < Struct.new( :bucket, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |