Class: Aws::S3Files::Types::ListMountTargetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Files::Types::ListMountTargetsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3files/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_point_id ⇒ String
Optional filter to list only mount targets associated with the specified access point ID or Amazon Resource Name (ARN).
-
#file_system_id ⇒ String
Optional filter to list only mount targets associated with the specified S3 File System ID or Amazon Resource Name (ARN).
-
#max_results ⇒ Integer
The maximum number of mount targets to return in a single response.
-
#next_token ⇒ String
A pagination token returned from a previous call to continue listing mount targets.
Instance Attribute Details
#access_point_id ⇒ String
Optional filter to list only mount targets associated with the specified access point ID or Amazon Resource Name (ARN).
1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/aws-sdk-s3files/types.rb', line 1159 class ListMountTargetsRequest < Struct.new( :file_system_id, :access_point_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#file_system_id ⇒ String
Optional filter to list only mount targets associated with the specified S3 File System ID or Amazon Resource Name (ARN). If provided, only mount targets for this file system will be returned in the response.
1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/aws-sdk-s3files/types.rb', line 1159 class ListMountTargetsRequest < Struct.new( :file_system_id, :access_point_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of mount targets to return in a single response.
1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/aws-sdk-s3files/types.rb', line 1159 class ListMountTargetsRequest < Struct.new( :file_system_id, :access_point_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token returned from a previous call to continue listing mount targets.
1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/aws-sdk-s3files/types.rb', line 1159 class ListMountTargetsRequest < Struct.new( :file_system_id, :access_point_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |